@@ -59,7 +59,6 @@
 #define CATEGORIES_FILE "xfce-registered-categories.xml"
 
 static void menu_dentry_legacy_init();
-G_INLINE_FUNC gboolean menu_dentry_legacy_need_update(XfceDesktopMenu *desktop_menu);
 static void menu_dentry_legacy_add_all(XfceDesktopMenu *desktop_menu,
         MenuPathType pathtype);
 
@@ -87,7 +86,7 @@ static gchar **legacy_dirs = NULL;
 static GHashTable *dir_to_cat = NULL;
 
 /* we don't want most command-line parameters if they're given. */
-G_INLINE_FUNC gchar *
+static inline gchar *
 _sanitise_dentry_cmd(gchar *cmd)
 {
     gchar *p;
@@ -101,7 +100,7 @@ _sanitise_dentry_cmd(gchar *cmd)
     return cmd;
 }
 
-G_INLINE_FUNC gint
+static inline gint
 _get_path_depth(const gchar *path)
 {
     gchar *p;
@@ -173,6 +172,7 @@ _menu_shell_insert_sorted(GtkMenuShell *menu_shell, GtkWidget *mi,
         if(cmpname && g_ascii_strcasecmp(name, cmpname) < 0)
             break;
     }
+    g_list_free(items);
     
     gtk_menu_shell_insert(menu_shell, mi, i);
     
