@@ -178,7 +178,7 @@ button_cb(GtkWidget *w, GdkEventButton *evt, gpointer user_data)
             popup_windowlist(gscreen, button, evt->time);
             return TRUE;
         } else if(button == 3 || (button == 1 && (state & GDK_SHIFT_MASK))) {
-            popup_desktop_menu(gscreen, button, evt->time);
+            popup_desktop_menu(gscreen, 0, evt->time);
             return TRUE;
         }
     }
@@ -382,8 +382,8 @@ main(int argc, char **argv)
     windowlist_set_show_icons(desktop_gtk_menu_images);
     
     if(mcs_client) {
-        settings_register_callback(menu_settings_changed, NULL);
-        settings_register_callback(windowlist_settings_changed, NULL);
+        settings_register_callback(menu_settings_changed, desktops[0]);
+        settings_register_callback(windowlist_settings_changed, desktops[0]);
     }
     
     signal(SIGHUP, sighandler_cb);
